@@ -1,4 +1,5 @@
 from devpi_server.config import MyArgumentParser, parseoptions
+from devpi_server.main import Fatal
 import pytest
 
 class TestParser:
@@ -67,6 +68,52 @@ class TestConfig:
         config = parseoptions(["devpi-server"])
         assert config.serverdir == tmpdir
 
+    def test_role_permanence_master(self, tmpdir):
+        config = parseoptions(["devpi-server", "--serverdir", str(tmpdir)])
+        assert config.role == "master"
+        config = parseoptions(["devpi-server", "--role=master",
+                               "--serverdir", str(tmpdir)])
+        assert config.role == "master"
+        with pytest.raises(Fatal):
+            parseoptions(["devpi-server", "--role=replica",
+                          "--serverdir", str(tmpdir)])
+
+    def test_role_permanence_replica(self, tmpdir):
+        config = parseoptions(["devpi-server", "--master-url", "http://qwe",
+                               "--serverdir", str(tmpdir)])
+        assert config.role == "replica"
+        assert not config.get_master_uuid()
+        with pytest.raises(Fatal) as excinfo:
+            parseoptions(["devpi-server", "--serverdir", str(tmpdir)])
+        assert "specify --role=master" in str(excinfo.value)
+        config = parseoptions(["devpi-server", "--serverdir", str(tmpdir),
+                               "--role=master"])
+        assert config.role == "master"
+        with pytest.raises(Fatal):
+            parseoptions(["devpi-server", "--master-url=xyz",
+                          "--serverdir", str(tmpdir)])
+        with pytest.raises(Fatal):
+            parseoptions(["devpi-server", "--role=replica",
+                          "--serverdir", str(tmpdir)])
+
+    def test_replica_role_missing_master_url(self, tmpdir):
+        with pytest.raises(Fatal) as excinfo:
+            parseoptions(["devpi-server", "--role=replica",
+                          "--serverdir", str(tmpdir)])
+        assert "need to specify --master-url" in str(excinfo)
+
+    def test_uuid(self, tmpdir):
+        config = parseoptions(["devpi-server", "--serverdir", str(tmpdir)])
+        uuid = config.nodeinfo["uuid"]
+        assert uuid
+        assert config.get_master_uuid() == uuid
+        config = parseoptions(["devpi-server", "--serverdir", str(tmpdir)])
+        assert uuid == config.nodeinfo["uuid"]
+        tmpdir.remove()
+        config = parseoptions(["devpi-server", "--serverdir", str(tmpdir)])
+        assert config.nodeinfo["uuid"] != uuid
+        assert config.get_master_uuid() != uuid
+
     def test_add_parser_options_called(self):
         from devpi_server.config import PluginManager
         l = []
@@ -88,7 +135,7 @@ def test_pluginmanager_call():
     l = pm._call_plugins("meth1", x=1, y=2)
     assert len(l) == 1
     assert l[0] == 3
-    
+
 
 def test_load_setuptools_plugins(monkeypatch):
     from devpi_server.config import load_setuptools_entrypoints
