@@ -91,9 +91,17 @@ def test_simple_project_outside_url_subpath(mapp, outside_url, pypistage, testap
         200, URL("/%s/+simple/qpwoei" % api.stagename).joinpath(links[0]).path,
         headers=headers)
 
-def test_project_redirect(pypistage, testapp):
+
+@pytest.mark.parametrize(
+    "user_agent",
+    [
+        'pip/1.4.1',
+        'setuptools/6.1',
+        'pip/6.0.dev1 {"cpu":"x86_64","distro":{"name":"OS X","version":"10.9.5"},"implementation":{"name":"CPython","version":"2.7.8"},"installer":{"name":"pip","version":"6.0.dev1"},"python":"2.7.8","system":{"name":"Darwin","release":"13.4.0"}}'],
+    ids=['pip', 'setuptools', 'pip6'])
+def test_project_redirect(pypistage, testapp, user_agent):
     name = "qpwoei"
-    headers = {'User-Agent': str('pip/1.4.1'), "Accept": str("text/html")}
+    headers = {'User-Agent': str(user_agent), "Accept": str("text/html")}
 
     r = testapp.get("/root/pypi/%s" % name, headers=headers)
     assert r.status_code == 302
@@ -211,13 +219,19 @@ def test_indexroot_root_pypi(testapp, xom):
     assert r.status_code == 200
     assert b"in-stage" not in r.body
 
-@pytest.mark.parametrize("code", [-1, 500, 501, 502, 503])
-def test_upstream_not_reachable(pypistage, testapp, xom, code):
-    name = "whatever%d" % (code + 1)
-    pypistage.mock_simple(name, status_code = code)
-    r = testapp.get("/root/pypi/+simple/%s" % name)
+@pytest.mark.parametrize("url", [
+    '/root/pypi/{name}',
+    '/root/pypi/{name}/2.6',
+    '/root/pypi/+simple/{name}',
+])
+@pytest.mark.parametrize("code", [-1, 404, 500, 501, 502, 503])
+def test_upstream_not_reachable(reqmock, pypistage, testapp, code, url):
+    name = "whatever{code}".format(code=code+100)
+    pypistage.mock_simple(name, '', status_code=code)
+    r = testapp.get(url.format(name=name), accept="application/json")
     assert r.status_code == 502
 
+
 def test_pkgserv(httpget, pypistage, testapp):
     pypistage.mock_simple("package", '<a href="/package-1.0.zip" />')
     httpget.setextfile("/package-1.0.zip", b"123")
